<?php
$TRANSLATIONS = array(
"Unable to switch channel." => "Kon niet van kanaal wisselen.",
"Version not found" => "Versie niet gevonden",
"Upgrade is not possible. Your web server does not have permission to remove the following directory:" => "Bijwerken is niet mogelijk. Uw webserver heeft geen permissie om de volgende directory re verwijderen:",
"Update permissions on this directory and its content or remove it manually first." => "Werk de permissies op deze directory en de inhoud bij , of verwijder ze eerst handmatig.",
"Update failed." => "Bijwerken mislukt.",
"Fetching..." => "Ophalen...",
"<strong>The update was unsuccessful.</strong><br />Please check the logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>." => "<strong>De update is mislukt.</strong> Controleer de logs op de beheerpagina en meld het probleem aan de <a href=\"https://github.com/owncloud/apps/issues\" target=\"_blank\">ownCloud community</a>.",
"<strong>Server error.</strong> Please check the web server log file for details." => "<strong>Server fout.</strong> Verifieer het webserver logbestand voor details.",
"Retry" => "Opniew",
"Here is your backup:" => "Hier is uw backup:",
"Proceed" => "Ga verder",
"<strong>All done.</strong> Click to the link below to start database upgrade." => "<strong>Alles gedaan.</strong> Klik op onderstaande link om de database bij te werken.",
"Production" => "Productie",
"Stable" => "Stabiel",
"Beta" => "Beta",
"Daily" => "Dagelijks",
"Please ask your server administrator to enable PHP zip extension." => "Vraag uw server beheerder om de PHP zip extensie te activeren.",
"Not possible to update %s to %s. Downgrading or skipping major releases is not supported." => "Kan %s niet bijwerken naar %s. Terugdraaien of overslaan van een hoofdrelease is niet ondersteund.",
"Make sure that your web server has read access to the following files and directories:" => "Controleer of uw webserver leesrechten heeft op de volgende bestanden en directories:",
"Make sure that your web server has write access to the following files and directories:" => "Controleer of uw webserver schrijfrechten heeft op de volgende bestanden en directories:",
"Updates" => "Updates",
"<strong>A new version is available: {{newVersion}}</strong>" => "<strong>Er is een nieuwe versie beschikbaar: {{newVersion}}</strong>",
"Testing is everything: Therefore updates will be available here within a few days after the announcement." => "Testen is alles. Daarom komen updates hier een paar dagen na de aankondiging beschikbaar.",
"<strong>Your version is up to date.</strong>" => "<strong>Uw versie is up to date.</strong>",
"Checked on {{checkedAt}}" => "Gecontroleerd op {{checkedAt}}",
"1. Check & Backup" => "1. Controleer en back-up",
"2. Download & Extract" => "2. Download en pak uit",
"3. Replace" => "3. Vervangen",
"Update" => "Bijwerken",
"Update channel:" => "Bijwerkkanaal:",
"<em>Rule of thumb: You can always update to a newer version. But you can never downgrade to a lower version number. Keep that in mind while using experimental channels." => "<em>Vuistregel: U kunt altijd bijwerken naar een nieuwere versie. Maar teruug naar een ouder versienummer is niet mogelijk. Onthoud dat als u werkt met experimentele versies.",
"Updater-Backups" => "Updater-Backups",
"Take your time for a backup strategy: <strong>This app will only backup core files (no personal data).</strong>" => "Denk na over uw backup strategie: <strong>Deze app backupt alleen kernbestanden (geen persoonlijke bestanden).</strong>",
"<strong>Important: Please always do a separate backup of database and personal data before updating.</strong>" => "<strong>Belangrijk: Maak altiojd een aparte backup van de database en persoonlijke gegevens voor het bijwerken.</strong>",
"No backups found." => "Geen backups gevonden",
"Backup" => "Back-up",
"Done on" => "Uitgevoerd op",
"Size" => "Grootte",
"Download" => "Downloaden",
"Delete" => "Verwijder",
"Are you sure you want to delete {{entry.title}}" => "Weet u zeker dat u {{entry.title}} wilt verwijderen?",
"Backup directory" => "Back-up map"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
